@@ -4,7 +4,7 @@
 # triads.h
 #
 # copyright (c) 2004, Carter T. Butts <buttsc@uci.edu>
-# Last Modified 11/13/04
+# Last Modified 4/24/05
 # Licensed under the GNU General Public License version 2 (June, 1991)
 #
 # Part of the R/sna package
@@ -24,13 +24,13 @@
 
 
 /*INTERNAL ROUTINES---------------------------------------------------------*/
-int triad_classify(int *g, int gn, int i, int j, int k);
+int triad_classify(int *g, int gn, int i, int j, int k, int gm);
 
 
 /*R-CALLABLE ROUTINES-------------------------------------------------------*/
 
-void triad_census_R(int *g, int *n, double *t);
-void triad_classify_R(int *g, int *tt);
+void triad_census_R(int *g, int *n, double *t, int *gm);
+void triad_classify_R(int *g, int *tt, int *gm);
 
 
 #endif
